@@ -2,9 +2,10 @@
 
 from __future__ import unicode_literals, print_function, with_statement
 
-__version__ = '3.0.1'
+__version__ = '5.0.1'
 __author__ = 'Santiago Debus - Grow HQ, Inc.'
 __license__ = 'MIT'
 
 from .zipfly import ZipFly
-from .api import from_one_file
+from .response import FileResponse
+from .api import Buffer
